# Scikit-Learn models for LensKit

> [!NOTE]
> This package is deprecated — install `lenskit[sklearn]` instead.

The `lenskit-sklearn` package provides various recommendation components for [LensKit][] using [Scikit-Learn][] models for scoring.

[Scikit-Learn]: https://scikit-learn.org
[LensKit]: https://lkpy.lenskit.org
